@@ -2,16 +2,17 @@
 model = dict(
     type='YOLOv6l',
     pretrained=None,
-    depth_multiple=1.0,
+    depth_multiple=1.0,  
     width_multiple=1.0,
     backbone=dict(
         type='CSPBepBackbone',
         num_repeats=[1, 6, 12, 18, 6],
         out_channels=[64, 128, 256, 512, 1024],
         csp_e=float(1)/2,
+        fuse_P2=True,
         ),
     neck=dict(
-        type='CSPRepPANNeck',
+        type='CSPRepBiFPANNeck',
         num_repeats=[12, 12, 12, 12],
         out_channels=[256, 128, 128, 256, 256, 512],
         csp_e=float(1)/2,
@@ -21,9 +22,13 @@ model = dict(
         in_channels=[128, 256, 512],
         num_layers=3,
         begin_indices=24,
-        anchors=1,
+        anchors=3,
+        anchors_init=[[10,13, 19,19, 33,23], 
+                      [30,61, 59,59, 59,119], 
+                      [116,90, 185,185, 373,326]],
         out_indices=[17, 20, 23],
         strides=[8, 16, 32],
+        atss_warmup_epoch=0,
         iou_type='giou',
         use_dfl=True,
         reg_max=16, #if use_dfl is False, please set reg_max to 0
@@ -43,12 +48,12 @@ solver=dict(
     weight_decay=0.0005,
     warmup_epochs=3.0,
     warmup_momentum=0.8,
-    warmup_bias_lr=0.1
+    warmup_bias_lr=0.1       
 )
-
+ 
 data_aug = dict(
-    hsv_h=0.015,
-    hsv_s=0.7,
+    hsv_h=0.015,  
+    hsv_s=0.7, 
     hsv_v=0.4,
     degrees=0.0,
     translate=0.1,
@@ -59,5 +64,5 @@ data_aug = dict(
     mosaic=1.0,
     mixup=0.1,
 )
-training_mode = "conv_silu"
+training_mode = "conv_silu" 
 # use normal conv to speed up training and further improve accuracy.
